/*--------------------------------------------------------------------------*/
/* ALBERTA:  an Adaptive multi Level finite element toolbox using           */
/*           Bisectioning refinement and Error control by Residual          */
/*           Techniques for scientific Applications                         */
/*                                                                          */
/* file:     face_quad_fast.h                                               */
/*                                                                          */
/* description:  header file for fast (i.e. caching) quadrature over faces  */
/*                                                                          */
/*--------------------------------------------------------------------------*/
/*                                                                          */
/*  authors:   Alfred Schmidt                                               */
/*             Zentrum fuer Technomathematik                                */
/*             Fachbereich 3 Mathematik/Informatik                          */
/*             Universitaet Bremen                                          */
/*             Bibliothekstr. 2                                             */
/*             D-28359 Bremen, Germany                                      */
/*                                                                          */
/*             Kunibert G. Siebert                                          */
/*             Institut fuer Mathematik                                     */
/*             Universitaet Augsburg                                        */
/*             Universitaetsstr. 14                                         */
/*             D-86159 Augsburg, Germany                                    */
/*                                                                          */
/*             Claus-Justus Heine                                           */
/*             Abteilung fuer Angewandte Mathematik                         */
/*             Albert-Ludwigs-Universitaet Freiburg                         */
/*             Hermann-Herder-Str. 10                                       */
/*             D-79104 Freiburg im Breisgau, Germany                        */
/*                                                                          */
/*  http://www.alberta-fem.de/                                              */
/*                                                                          */
/*--------------------------------------------------------------------------*/
/*  (c) by A. Schmidt and K.G. Siebert (1996-2004)                          */
/*         C.-J. Heine (1998-2004)                                          */
/*                                                                          */
/*     This program is free software; you can redistribute it and/or modify */
/*     it under the terms of the GNU General Public License as published by */
/*     the Free Software Foundation; either version 2 of the License, or    */
/*     any later version.                                                   */
/*                                                                          */
/*     This program is distributed in the hope that it will be useful,      */
/*     but WITHOUT ANY WARRANTY; without even the implied warranty of       */
/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
/*     GNU General Public License for more details.                         */
/*--------------------------------------------------------------------------*/
#ifndef _ALBERTA_FACE_QUAD_FAST_
#define _ALBERTA_FACE_QUAD_FAST_

#include "alberta.h"

#ifdef __cplusplus 
extern "C" {
#endif

#if DIM == 2 && !defined(N_FACES)
# define N_FACES N_EDGES
#endif

  typedef struct face_quad_fast FACE_QUAD_FAST;

  struct face_quad_fast
  {
    const QUAD             *quad;

    int                    n_points;
    int                    n_bas_fcts;
    const REAL             *w;
    const REAL             (*lambda[N_FACES])[DIM+1];
    U_CHAR                 init_flag;

    REAL                   **phi[N_FACES];

    FACE_QUAD_FAST         *next;
    BAS_FCTS               *bas_fcts;

    REAL                   (**grd_phi[N_FACES])[DIM+1];
    REAL                   (**D2_phi[N_FACES])[DIM+1][DIM+1];
    /* qp_n = sorted[face][qp][face_n] gives the index into
     * lambda[face_n] so that lambda[qp_n] are the barycentric
     * coordinates of the quadrature node, but relative to a neighbour
     * which's face numbering designates the index "face_n" to this
     * face.
     *
     */
    int                    *sorted[N_FACES][N_FACES];
  };

  const FACE_QUAD_FAST *get_face_quad_fast(const BAS_FCTS *, const QUAD *, 
					   U_CHAR init_flag);

#ifdef __cplusplus 
}
#endif

#endif
