/*--------------------------------------------------------------------------*/
/*  PLOT_ANSI: package for simple 2d X11 graphics                           */
/*                                                                          */
/*  (c) by A. Schmidt (1990-2004)                                           */
/*                                                                          */
/*     This program is free software; you can redistribute it and/or modify */
/*     it under the terms of the GNU General Public License as published by */
/*     the Free Software Foundation; either version 2 of the License, or    */
/*     any later version.                                                   */
/*                                                                          */
/*     This program is distributed in the hope that it will be useful,      */
/*     but WITHOUT ANY WARRANTY; without even the implied warranty of       */
/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
/*     GNU General Public License for more details.                         */
/*--------------------------------------------------------------------------*/

#include <stdio.h>

#include <fcntl.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>

#define single 

#include "PLOTansi.h"


/**********************************************************************
  WindowHandle *PLOT_create_window(name,geometry)
       char *name,*geometry;

  create a new current PLOT window with given name and default geometry
***********************************************************************/

PLOT_INFO *.plot_create_window(name,geometry)
     char **name,**geometry;
{
  extern PLOT_INFO *PLOT_create_window();

  return(PLOT_create_window(*name,*geometry));
}



/**********************************************************************
  void PLOT_destroy_window()

  destroy a PLOT window
***********************************************************************/

void .plot_destroy_window(info)
     PLOT_INFO **info;
{
  extern void PLOT_destroy_window();
  PLOT_destroy_window(*info);
}



/**********************************************************************
  PLOT_INFO *PLOT_get_std_window()

  return PLOT_INFO of current PLOT window
***********************************************************************/

/*PLOT_INFO *PLOT_GET_STD_WINDOW()*/
int .plot_get_std_window()
{
  extern PLOT_INFO *PLOT_get_std_window();
  int i;
  i = (int)PLOT_get_std_window();
  return(i);
}



/**********************************************************************
  PLOT_INFO *PLOT_set_std_window(new_window)
       PLOT_INFO *new_window;

  set current PLOT window to new_window
  return PLOT_INFO of previously current PLOT window
***********************************************************************/

PLOT_INFO *.plot_set_std_window(new_window)
     int *new_window;
/*     PLOT_INFO **new_window;*/
{
  extern PLOT_INFO *PLOT_set_std_window();
  PLOT_INFO *info;

  info = (PLOT_INFO *)*new_window;

  return(PLOT_set_std_window(info));
}





/**********************************************************************
  PLOT_expose(window)
       Window window;

  recalculate window size after an expose
***********************************************************************/

.plot_expose(window)
     Window *window;
{
  PLOT_expose(*window);
}




/**********************************************************************
  PLOT_title(title)
       char *title

  set title of current PLOT window
***********************************************************************/

.plot_title(title)
     char **title;
{
  PLOT_title(*title);
}




/**********************************************************************
  PLOT_alarm(sec)
       unsigned sec;

  start the alarm window handler with interval of <sec> seconds
***********************************************************************/

.plot_alarm(sec)
     unsigned *sec;
{
  PLOT_alarm(*sec);
}




/************************ icolor ************/

.plot_set_icolor(icolor)
    int *icolor;
{
  PLOT_set_icolor(*icolor);
}

.plot_get_icolor(icolor)
    int *icolor;
{
  PLOT_get_icolor(*icolor);
}


/************************ background color ************/

.plot_set_backgroundcolor(color)
    float color[3];
{
  PLOT_set_backgroundcolor(color);
}

.plot_get_backgroundcolor(color)
    float color[3];
{
  PLOT_get_backgroundcolor(color);
}

/************************ line color ************/

.plot_set_linecolor(color)
     float color[3];
{
  PLOT_set_linecolor(color);
}

.plot_get_linecolor(color)
     float color[3];
{
  PLOT_get_linecolor(color);
}

/************************ patch color ************/

.plot_set_patchcolor(color)
     float color[3];
{
  PLOT_set_patchcolor(color);
}

.plot_get_patchcolor(color)
     float color[3];
{
  PLOT_get_patchcolor(color);
}

/************************ text color ************/

.plot_set_textcolor(color)
     float color[3];
{
  PLOT_set_textcolor(color);
}

.plot_get_textcolor(color)
     float color[3];
{
  PLOT_get_textcolor(color);
}




/******************************************************************
  Flush
******************************************************************/

.plot_flush()
{
  PLOT_flush();
}




/******************************************************************
  Clear
******************************************************************/

.plot_clear()
{
  PLOT_clear();
}




/******************************************************************
  Transformations
******************************************************************/

.plot_set_transform2d(mtype, mat)
     int *mtype;
     float mat[3][3];
{
  PLOT_set_transform2d(*mtype, mat);
}



.plot_get_transform2d(mtype, mat)
     int *mtype;
     float mat[3][3];
{
  PLOT_get_transform2d(*mtype, mat);
}

.plot_world2d(float *xmin, float *xmax, float *ymin, float *ymax)
{
  PLOT_world2d(*xmin, *xmax, *ymin, *ymax);
}



/******************************************************************
  Move
******************************************************************/

.plot_move2d(x,y)
     float *x,*y;
{
  PLOT_move2d(*x,*y);
}


.plot_vmove2d(vec)
     float vec[2];
{
  PLOT_vmove2d(vec);
}



/******************************************************************
  Draw
******************************************************************/

.plot_draw2d(x,y)
     float *x,*y;
{
  PLOT_draw2d(*x,*y);
}


.plot_vdraw2d(vec)
     float vec[2];
{
  PLOT_vdraw2d(vec);
}


/******************************************************************
  Line
******************************************************************/

.plot_line2d(x1,y1, x2,y2)
     float *x1,*y1,*x2,*y2;
{
  PLOT_line2d(*x1,*y1, *x2,*y2);
}


.plot_vline2d(vec1,vec2)
     float vec1[2],vec2[2];
{
  PLOT_vline2d(vec1,vec2);
}


/******************************************************************
  triangle
******************************************************************/

.plot_triangle2d(x1,y1, x2,y2, x3,y3)
     float *x1,*y1,*x2,*y2,*x3,*y3;
{
  PLOT_triangle2d(*x1,*y1, *x2,*y2, *x3,*y3);
}


.plot_vtriangle2d(vec1,vec2,vec3)
     float vec1[2],vec2[2],vec3[2];
{
  PLOT_vtriangle2d(vec1,vec2,vec3);
}



.plot_trianglergb2d(x1,y1, x2,y2, x3,y3, rgb1,rgb2,rgb3)
     float *x1,*y1,*x2,*y2,*x3,*y3;
     float rgb1[3],rgb2[3],rgb3[3];
{
  PLOT_triangleRGB2d(*x1,*y1, *x2,*y2, *x3,*y3, rgb1,rgb2,rgb3);
}


.plot_vtrianglergb2d(vec1,vec2,vec3, rgb1,rgb2,rgb3)
     float vec1[2],vec2[2],vec3[2];
     float rgb1[3],rgb2[3],rgb3[3];
{
  PLOT_vtriangleRGB2d(vec1,vec2,vec3, rgb1,rgb2,rgb3);
}



/******************************************************************
  text
******************************************************************/


.plot_text2d(x,y,string)
     float *x,*y;
     char **string;
{
  PLOT_text2d(*x,*y,*string);
}



.plot_vtext2d(vec,string)
     float vec[2];
     char **string;
{
  PLOT_vtext2d(vec,*string);
}


