/*--------------------------------------------------------------------------*/
/*  PLOT_ANSI: package for simple 2d X11 graphics                           */
/*                                                                          */
/*  (c) by A. Schmidt (1990-2004)                                           */
/*                                                                          */
/*     This program is free software; you can redistribute it and/or modify */
/*     it under the terms of the GNU General Public License as published by */
/*     the Free Software Foundation; either version 2 of the License, or    */
/*     any later version.                                                   */
/*                                                                          */
/*     This program is distributed in the hope that it will be useful,      */
/*     but WITHOUT ANY WARRANTY; without even the implied warranty of       */
/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
/*     GNU General Public License for more details.                         */
/*--------------------------------------------------------------------------*/

#include <stdio.h>

#include <fcntl.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>

#define single 

#include "PLOTansi.h"


/**********************************************************************
  WindowHandle *PLOT_create_window(name,geometry)
       char *name,*geometry;

  create a new current PLOT window with given name and default geometry
***********************************************************************/

PLOT_INFO *plot_create_window_(char *name, char *geometry)
{
  return(PLOT_create_window(name,geometry));
}



/**********************************************************************
  void PLOT_destroy_window()

  destroy a PLOT window
***********************************************************************/

void plot_destroy_window_(PLOT_INFO **info)
{
  PLOT_destroy_window(*info);
}



/**********************************************************************
  PLOT_INFO *PLOT_get_std_window()

  return PLOT_INFO of current PLOT window
***********************************************************************/

/*PLOT_INFO *PLOT_GET_STD_WINDOW()*/
int plot_get_std_window_(void)
{
  int i;
  i = (int)PLOT_get_std_window();
  return(i);
}



/**********************************************************************
  PLOT_INFO *PLOT_set_std_window(new_window)
       PLOT_INFO *new_window;

  set current PLOT window to new_window
  return PLOT_INFO of previously current PLOT window
***********************************************************************/

PLOT_INFO *plot_set_std_window_(int *new_window)
{
  PLOT_INFO *info;

  info = (PLOT_INFO *)*new_window;

  return(PLOT_set_std_window(info));
}





/**********************************************************************
  PLOT_expose(window)
       Window window;

  recalculate window size after an expose
***********************************************************************/

void plot_expose_(Window *window)
{
  PLOT_expose(*window);
}




/**********************************************************************
  PLOT_title(title)
       char *title

  set title of current PLOT window
***********************************************************************/

void plot_title_(char *title)
{
  PLOT_title(title);
}




/**********************************************************************
  PLOT_alarm(sec)
       unsigned sec;

  start the alarm window handler with interval of <sec> seconds
***********************************************************************/

void plot_alarm_(unsigned *sec)
{
  PLOT_alarm(*sec);
}




/************************ icolor ************/

void plot_set_icolor_(int *icolor)
{
  PLOT_set_icolor(*icolor);
}

void plot_get_icolor_(int *icolor)
{
  PLOT_get_icolor(icolor);
}


/************************ background color ************/

void plot_set_backgroundcolor_(float color[3])
{
  PLOT_set_backgroundcolor(color);
}

void plot_get_backgroundcolor_(float color[3])
{
  PLOT_get_backgroundcolor(color);
}

/************************ line color ************/

void plot_set_linecolor_(float color[3])
{
  PLOT_set_linecolor(color);
}

void plot_get_linecolor_(float color[3])
{
  PLOT_get_linecolor(color);
}

/************************ patch color ************/

void plot_set_patchcolor_(float color[3])
{
  PLOT_set_patchcolor(color);
}

void plot_get_patchcolor_(float color[3])
{
  PLOT_get_patchcolor(color);
}

/************************ text color ************/

void plot_set_textcolor_(float color[3])
{
  PLOT_set_textcolor(color);
}

void plot_get_textcolor_(float color[3])
{
  PLOT_get_textcolor(color);
}




/******************************************************************
  Flush
******************************************************************/

void plot_flush_(void)
{
  PLOT_flush();
}




/******************************************************************
  Clear
******************************************************************/

void plot_clear_(void)
{
  PLOT_clear();
}




/******************************************************************
  Transformations
******************************************************************/

void plot_set_transform2d_(int *mtype, float mat[3][3])
{
  PLOT_set_transform2d(*mtype, mat);
}



void plot_get_transform2d_(int *mtype, float mat[3][3])
{
  PLOT_get_transform2d(*mtype, mat);
}


void plot_world2d_(float *xmin, float *xmax, float *ymin, float *ymax)
{
  PLOT_world2d(*xmin, *xmax, *ymin, *ymax);
}

/******************************************************************
  Move
******************************************************************/

void plot_move2d_(float *x, float *y)
{
  PLOT_move2d(*x,*y);
}


void plot_vmove2d_(float vec[2])
{
  PLOT_vmove2d(vec);
}



/******************************************************************
  Draw
******************************************************************/

void plot_draw2d_(float *x, float *y)
{
  PLOT_draw2d(*x,*y);
}


void plot_vdraw2d_(float vec[2])
{
  PLOT_vdraw2d(vec);
}


/******************************************************************
  Line
******************************************************************/

void plot_line2d_(float *x1, float *y1, float *x2, float *y2)
{
  PLOT_line2d(*x1,*y1, *x2,*y2);
}


void plot_vline2d_(float vec1[2], float vec2[2])
{
  PLOT_vline2d(vec1,vec2);
}


/******************************************************************
  triangle
******************************************************************/

void plot_triangle2d_(float *x1, float *y1, float *x2, float *y2,
		      float *x3, float *y3)
{
  PLOT_triangle2d(*x1,*y1, *x2,*y2, *x3,*y3);
}


void plot_vtriangle2d_(float vec1[2], float vec2[2], float vec3[2])
{
  PLOT_vtriangle2d(vec1,vec2,vec3);
}



void plot_trianglergb2d_(float *x1, float *y1, float *x2, float *y2,
			 float *x3, float *y3,
			 float rgb1[3], float rgb2[3], float rgb3[3])
{
  PLOT_triangleRGB2d(*x1,*y1, *x2,*y2, *x3,*y3, rgb1,rgb2,rgb3);
}


void plot_vtrianglergb2d_(float vec1[2], float vec2[2], float vec3[2],
			  float rgb1[3], float rgb2[3], float rgb3[3])
{
  PLOT_vtriangleRGB2d(vec1,vec2,vec3, rgb1,rgb2,rgb3);
}



/******************************************************************
  text
******************************************************************/


void plot_text2d_(float *x, float *y, char *string)
{
  PLOT_text2d(*x,*y,string);
}


void plot_vtext2d_(float vec[2], char *string)
{
  PLOT_vtext2d(vec,string);
}


